@@ -1,13 +1,17 @@
 import json
 from datetime import date, datetime, time
+from tempfile import NamedTemporaryFile
 from unittest import skipIf
 
 import pytz
+import yaml
 from django.core.exceptions import ImproperlyConfigured
 from django.shortcuts import render
 from django.test import TestCase
+from openpyxl import load_workbook
 
 import django_tables2 as tables
+from django_tables2 import A
 from django_tables2.config import RequestConfig
 
 from .app.models import Occupation, Person, Region
@@ -41,8 +45,8 @@ class Table(tables.Table):
 
 
 class AccessorTable(tables.Table):
-    given_name = tables.Column(accessor=tables.A("first_name"), verbose_name="Given name")
-    surname = tables.Column(accessor=tables.A("last_name"))
+    given_name = tables.Column(accessor=A("first_name"), verbose_name="Given name")
+    surname = tables.Column(accessor=A("last_name"))
 
 
 class View(ExportMixin, tables.SingleTableView):
@@ -97,9 +101,7 @@ class TableExportTest(TestCase):
             Person.objects.create(first_name=first_name, last_name=last_name, occupation=programmer)
 
         class AccessorRelationTable(AccessorTable):
-            occupation = tables.Column(
-                accessor=tables.A("occupation.name"), verbose_name="Occupation"
-            )
+            occupation = tables.Column(accessor=A("occupation__name"), verbose_name="Occupation")
 
         table = AccessorRelationTable(Person.objects.all())
 
@@ -109,6 +111,26 @@ class TableExportTest(TestCase):
         )
         self.assertEqual(exporter.export(), CSV_SEP.join(expected) + CSV_SEP)
 
+    def test_export_dataset_kwargs(self):
+        table = Table(
+            [
+                {"first_name": "Yildiz", "last_name": "van der Kuil"},
+                {"first_name": "Jan", "last_name": None},
+            ]
+        )
+        title = "My Custom Title"
+        exporter = TableExport("xlsx", table, dataset_kwargs={"title": title})
+        self.assertEqual(exporter.dataset.title, title)
+
+    def test_export_default_dataset_title(self):
+        class PersonTable(Table):
+            class Meta:
+                model = Person  # provides default title
+
+        table = PersonTable(Person.objects.all())
+        exporter = TableExport("xlsx", table)
+        self.assertEqual(exporter.dataset.title, Person._meta.verbose_name_plural.title())
+
 
 @skipIf(TableExport is None, "Tablib is required to run the export tests")
 class ExportViewTest(TestCase):
@@ -137,6 +159,12 @@ class ExportViewTest(TestCase):
         response = View.as_view()(build_request("/?_export=json"))
         self.assertEqual(json.loads(response.getvalue().decode("utf8")), EXPECTED_JSON)
 
+    def test_should_support_yaml_export(self):
+        response = View.as_view()(build_request("/?_export=yaml"))
+        self.assertEqual(
+            yaml.load(response.getvalue().decode("utf8"), Loader=yaml.FullLoader), EXPECTED_JSON
+        )
+
     def test_should_support_custom_trigger_param(self):
         class View(ExportMixin, tables.SingleTableView):
             table_class = Table
@@ -179,6 +207,23 @@ class ExportViewTest(TestCase):
         self.assertIn("Yildiz", html)
         self.assertNotIn("Lindy", html)
 
+    def test_should_support_custom_dataset_kwargs(self):
+        title = "The Sheet Name"
+
+        class View(ExportMixin, tables.SingleTableView):
+            table_class = Table
+            model = Person  # required for ListView
+            dataset_kwargs = {"title": title}
+
+        response = View.as_view()(build_request("/?_export=xlsx"))
+        self.assertEqual(response.status_code, 200)
+
+        with NamedTemporaryFile(suffix=".xlsx") as tmp:
+            tmp.write(response.content)
+            tmp.seek(0)
+            wb = load_workbook(tmp.name)
+            self.assertIn(title, wb.sheetnames)
+
 
 class OccupationTable(tables.Table):
     name = tables.Column()
@@ -280,7 +325,7 @@ class AdvancedExportViewTest(TestCase):
             name = tables.Column()
             boolean = tables.Column()
             region = tables.Column()
-            mayor = tables.Column(accessor="region.mayor.first_name")
+            mayor = tables.Column(accessor="region__mayor__first_name")
 
         class View(ExportMixin, tables.SingleTableView):
             table_class = OccupationWithForeignKeyFieldsTable
